==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebComboChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComboChangeEventArgsDetailDescriptionMetadata } from "./WebComboChangeEventArgsDetailDescriptionMetadata";
import { WebComboChangeEventArgsDescription } from "./WebComboChangeEventArgsDescription";
/**
 * @hidden
 */
var WebComboChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComboChangeEventArgsDescriptionMetadata, _super);
    function WebComboChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebComboChangeEventArgsDescriptionMetadata.a == null) {
            WebComboChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComboChangeEventArgsDescriptionMetadata.c(WebComboChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebComboChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebComboChangeEventArgsDescriptionMetadata.a);
        WebComboChangeEventArgsDetailDescriptionMetadata.d(a);
    };
    WebComboChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComboChangeEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebComboChangeEventArgsDetail");
    };
    WebComboChangeEventArgsDescriptionMetadata.d = function (a) {
        WebComboChangeEventArgsDescriptionMetadata.b(a);
        a.ad("WebComboChangeEventArgs", function () { return new WebComboChangeEventArgsDescription(); });
        a.ac("WebComboChangeEventArgs", WebComboChangeEventArgsDescriptionMetadata.a);
    };
    WebComboChangeEventArgsDescriptionMetadata.$t = markType(WebComboChangeEventArgsDescriptionMetadata, 'WebComboChangeEventArgsDescriptionMetadata');
    WebComboChangeEventArgsDescriptionMetadata.a = null;
    return WebComboChangeEventArgsDescriptionMetadata;
}(Base));
export { WebComboChangeEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/WebComboChangeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComboChangeEventArgsDetailDescriptionMetadata } from "./WebComboChangeEventArgsDetailDescriptionMetadata";
import { WebComboChangeEventArgsDescription } from "./WebComboChangeEventArgsDescription";
/**
 * @hidden
 */
var WebComboChangeEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComboChangeEventArgsDescriptionMetadata, _super);
    function WebComboChangeEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebComboChangeEventArgsDescriptionMetadata.b = function (a) {
        if (WebComboChangeEventArgsDescriptionMetadata.a == null) {
            WebComboChangeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebComboChangeEventArgsDescriptionMetadata.c(WebComboChangeEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebComboChangeEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebComboChangeEventArgsDescriptionMetadata.a);
        WebComboChangeEventArgsDetailDescriptionMetadata.d(a);
    };
    WebComboChangeEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ComboChangeEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebComboChangeEventArgsDetail");
    };
    WebComboChangeEventArgsDescriptionMetadata.d = function (a) {
        WebComboChangeEventArgsDescriptionMetadata.b(a);
        a.ae("WebComboChangeEventArgs", function () { return new WebComboChangeEventArgsDescription(); });
        a.ad("WebComboChangeEventArgs", WebComboChangeEventArgsDescriptionMetadata.a);
    };
    WebComboChangeEventArgsDescriptionMetadata.$t = markType(WebComboChangeEventArgsDescriptionMetadata, 'WebComboChangeEventArgsDescriptionMetadata');
    WebComboChangeEventArgsDescriptionMetadata.a = null;
    return WebComboChangeEventArgsDescriptionMetadata;
}(Base));
export { WebComboChangeEventArgsDescriptionMetadata };
